## Dataset Attribution
This dataset was created by Tamkin et and is licensed under the CC BY 4.0 Attribution License. 

- Original Source: [huggingface.co](https://huggingface.co/datasets/Anthropic/discrim-eval)
- License: [https://creativecommons.org/licenses/by/4.0/](https://creativecommons.org/licenses/by/4.0/)
- Changes Made: Only the `explicit.jsonl` part is stored here.
